# Changelog

## Version 0.1.3

- **Added**: Configurable checkpoint and writes collection feature.
- **Fixed**: List function bug.

This version introduces a new configurable checkpoint and writes collection feature